==> mingw-w64-openimageio-2.5.7.0-1.src.tar.zst: OpenImageIO-2.5.7.0/RELICENSING.md <==
New code entering the OpenImageIO repository from July 1 2023 onward is
subject to the [Apache 2.0 license](LICENSE.md).

Code dating from earlier than July 1 2023 was contributed under the [BSD
3-clause license](LICENSE-BSD-3-Clause.md), unless relicensed below.

The following copyright holders agree that all of their contributions
originally submitted to this project under the 3-Clause BSD License are hereby
relicensed to the Apache License, Version 2.0, and are submitted pursuant to
the Developer Certificate of Origin, version 1.1:

- Larry Gritz (@lgritz)
- Chris Kulla (fpsunflower)
- Brecht Van Lommel (brechtvl)
- Daniel Flehner Heen (apetrynet)
- Daniel Wyatt (dewyatt)
- Aras Pranckevičius (aras-p)
- Leszek Godlewski (inequation)
- Dalai Felinto (dfelinto)
- Jesse Yurkovich (jessey-git)
- Sergey Sharybin (sergeyvfx)
- Ray Molenkamp (LazyDodo)
- Nathan Rusch (nrusch)
- Ismael Cortes (leamsi)
- AdamMainsTL
- Sony Pictures Imageworks (cmstein, olegul, fpsunflower, brianhall77, jeremyselan, drg, richardssam, lecocqp)
- Richard Shaw (hobbes1069)
- Robert Matusewicz
- Mariusz Szczepańczyk (mszczepanczyk)
- Scott Wilson
- Kevin Brightwell (Nava2)
- Simon Boorer
- Alex Hughes (Ahuge)
- Alister Chowdhury
- Manuel Leonhardt (skycaptain)
- Alexandre Gauthier (MrKepzie)
- Mark Boorer (shootfast)
- Povilas Kanapickas (p12tic)
- Mikael Sundell
- Roman Zulak (marsupial)
- Autodesk (includes Thiago Ize, Elvic Liang, Wayne Arnold, William Krick, Brecht Van Lommel, Marcos Fajardo)
- Thiago Ize
- Nick Black (dankamongmen)
- Michel Lerenard (micler)
- Stefan Bruens (StefanBruens)
- David Gordon
- Claire Foster (c42f)
- Konrad Kleine (kwk)
- Simone Gasparini (simogasp)
- Radu Arjocu (ra-mt)
- Dominik Bartkiewicz (fafik23)
- 360highdynamicrangehdr (?)
- Leonid Onokhov (sopvop)
- Nuno Cardoso (npcardoso)
- Todica Ionut (360highdynamicrangehdr)
- Till Dechent (ttddee)
- Tom Knowles (knowlsie)
- SRHMorris
- Biswapriyo Nath (Biswa96)
- Edoardo Dominici (dedoardo)
- Frédéric Devernay (devernay)
- Simone Gasparini (simogasp)
- roelandschoukens
- Nayden Dochev (nayyden)
- Yann Lanthony (yann-lty)
- Benjamin Buch (bebuch)
- Joris Nijs (joris-nijs)
- Jan Honsbrok (Latios96)
- Matteo F. Vescovi (mfvescovi)
- Patrick Northon (patlefort)
- Eric Mehl (ericmehl)
- Xo Wang (GHF)
- etiam
- Fabien Servant (servantftechnicolor)
- Loïc Vital (mugulmd)
- Thomas Mansencal (Wētā FX)
- Brent Davis (btdavis)
- pwm1234-sri
- toxieainc
- demoulinv
- Julien Enche (jenche)
- Justin Israel
- xiaoxiaoafeifei
- Brad Smith (brad0)
- lmarz
- Seifeddine Dridi (seifeddinedridi)
- Daniel Dresser (danieldresser)
- Luc Bournaud (DevilishSpirits)
- Dennis Schridde (devurandom)
- Dieter De Baets (debaetsd)
- Gonzalo Garramuño (ggarra13)
- Alan Jones (@skyphyr)
- pumkinpal
- Christopher Crosetto (ccrosetto)
- Russell Greene (russelltg)
- Sam Richards (richardssam)
- Guillaume Chatelet (gchatelet)
- extrowerk
- Heiko Becker (heirecka)
- Mark Visser (mjmvisser)
- Harry Mallon (hjmallon)
- Henri Fousse (darkhorse64)
- Krzysztof Blicharski (blicharski)
- Hugh Macdonald (HughMacdonald)
- Pascal Lecocq (lecocqp)
- Ramon Montoya Vozmediano (rmv)
- Dan Wexler (danwexler)
- Jérôme Duval (korli)
- Tim Grant (timgrant)
- Shane Ambler (sambler)
- Wētā
- Kimball Thurston (kdt3rd)
- Anders Langlands (anderslanglands)
- Алексей (Alexpux)
- Fabien Castan (fabiencastan)
- Grégoire De Lillo (gregoire-dl)
- Edgar Velázquez-Armendáriz (edgarv)
- Malcolm Humphreys (malcolmhumphreys)
- johnfea
- Max Liani (maxliani)
- Michael Görner (v4hn)
- Philip Nemec (p-nemec)
- Google
- Nandan Dubey (ndubey)
- NVIDIA
- Jonathan Hearn (splidje)
- Michael Root
- Ott Tinn
- Lukas Shrangl (luhk)
- Manuel Gamito (mgamito)
- Rémi Achard (remia)
- Joseph Goldstone (JGoldstone)
- Matthew Levine (melevine)
- Yang Yang (yangyangl, but now cometyang)

**Prior authors, please submit a PR against this file that adds your name
above. If, at the time of your prior contributions, you were employed by a
company who would have owned your IP output, then please have someone from
that company who is authorized to do so submit a PR to add their company’s
name to the list under the statement in this file.**


---

Here are the instructions we have been given by the Linux Foundation for how
to document the contents of each file:

a. Files that consist of only contributions made entirely by companies that
   have submitted PRs as described above can have, once those PRs are merged,
   the BSD-3-Clause license information replaced with Apache-2.0 license
   information.

b. Files that contain contributions made after the change to the Apache-2.0
   license as the license for the project should include only the Apache-2.0
   license information.

c. Files that contain contributions made both before the Apache-2.0 license
   change and after the Apache-2.0 license change should include both
   BSD-3-Clause and Apache-2.0 license information. The SPDX identifier for
   these files is “BSD-3-Clause and Apache-2.0”.

d. Files that contain only contributions made prior to the Apache-2.0 license
   change should continue to include BSD-3-Clause license information (e.g.,
   no changes to BSD-3-Clause information included in those files).

==> mingw-w64-openimageio-2.5.9.0-1.src.tar.zst: OpenImageIO-2.5.9.0/RELICENSING.md <==
New code entering the OpenImageIO repository from July 1 2023 onward is
subject to the [Apache 2.0 license](LICENSE.md).

Code dating from earlier than July 1 2023 was contributed under the [BSD
3-clause license](LICENSE-BSD-3-Clause.md), unless relicensed below.

The following copyright holders agree that all of their contributions
originally submitted to this project under the 3-Clause BSD License are hereby
relicensed to the Apache License, Version 2.0, and are submitted pursuant to
the Developer Certificate of Origin, version 1.1:

- Larry Gritz (@lgritz)
- Chris Kulla (fpsunflower)
- Brecht Van Lommel (brechtvl)
- Daniel Flehner Heen (apetrynet)
- Daniel Wyatt (dewyatt)
- Aras Pranckevičius (aras-p)
- Leszek Godlewski (inequation)
- Dalai Felinto (dfelinto)
- Jesse Yurkovich (jessey-git)
- Sergey Sharybin (sergeyvfx)
- Ray Molenkamp (LazyDodo)
- Nathan Rusch (nrusch)
- Ismael Cortes (leamsi)
- AdamMainsTL
- Sony Pictures Imageworks (cmstein, olegul, fpsunflower, brianhall77, jeremyselan, drg, richardssam, lecocqp)
- Richard Shaw (hobbes1069)
- Robert Matusewicz
- Mariusz Szczepańczyk (mszczepanczyk)
- Scott Wilson
- Kevin Brightwell (Nava2)
- Simon Boorer
- Alex Hughes (Ahuge)
- Alister Chowdhury
- Manuel Leonhardt (skycaptain)
- Alexandre Gauthier (MrKepzie)
- Mark Boorer (shootfast)
- Povilas Kanapickas (p12tic)
- Mikael Sundell
- Roman Zulak (marsupial)
- Autodesk (includes Thiago Ize, Elvic Liang, Wayne Arnold, William Krick, Brecht Van Lommel, Marcos Fajardo)
- Thiago Ize
- Nick Black (dankamongmen)
- Michel Lerenard (micler)
- Stefan Bruens (StefanBruens)
- David Gordon
- Claire Foster (c42f)
- Konrad Kleine (kwk)
- Simone Gasparini (simogasp)
- Radu Arjocu (ra-mt)
- Dominik Bartkiewicz (fafik23)
- 360highdynamicrangehdr (?)
- Leonid Onokhov (sopvop)
- Nuno Cardoso (npcardoso)
- Todica Ionut (360highdynamicrangehdr)
- Till Dechent (ttddee)
- Tom Knowles (knowlsie)
- SRHMorris
- Biswapriyo Nath (Biswa96)
- Edoardo Dominici (dedoardo)
- Frédéric Devernay (devernay)
- Simone Gasparini (simogasp)
- roelandschoukens
- Nayden Dochev (nayyden)
- Yann Lanthony (yann-lty)
- Benjamin Buch (bebuch)
- Joris Nijs (joris-nijs)
- Jan Honsbrok (Latios96)
- Matteo F. Vescovi (mfvescovi)
- Patrick Northon (patlefort)
- Eric Mehl (ericmehl)
- Xo Wang (GHF)
- etiam
- Fabien Servant (servantftechnicolor)
- Loïc Vital (mugulmd)
- Thomas Mansencal (Wētā FX)
- Brent Davis (btdavis)
- pwm1234-sri
- toxieainc
- demoulinv
- Julien Enche (jenche)
- Justin Israel
- xiaoxiaoafeifei
- Brad Smith (brad0)
- lmarz
- Seifeddine Dridi (seifeddinedridi)
- Daniel Dresser (danieldresser)
- Luc Bournaud (DevilishSpirits)
- Dennis Schridde (devurandom)
- Dieter De Baets (debaetsd)
- Gonzalo Garramuño (ggarra13)
- Alan Jones (@skyphyr)
- pumkinpal
- Christopher Crosetto (ccrosetto)
- Russell Greene (russelltg)
- Sam Richards (richardssam)
- Guillaume Chatelet (gchatelet)
- extrowerk
- Heiko Becker (heirecka)
- Mark Visser (mjmvisser)
- Harry Mallon (hjmallon)
- Henri Fousse (darkhorse64)
- Krzysztof Blicharski (blicharski)
- Hugh Macdonald (HughMacdonald)
- Pascal Lecocq (lecocqp)
- Ramon Montoya Vozmediano (rmv)
- Dan Wexler (danwexler)
- Jérôme Duval (korli)
- Tim Grant (timgrant)
- Shane Ambler (sambler)
- Wētā
- Kimball Thurston (kdt3rd)
- Anders Langlands (anderslanglands)
- Алексей (Alexpux)
- Fabien Castan (fabiencastan)
- Grégoire De Lillo (gregoire-dl)
- Edgar Velázquez-Armendáriz (edgarv)
- Malcolm Humphreys (malcolmhumphreys)
- johnfea
- Max Liani (maxliani)
- Michael Görner (v4hn)
- Philip Nemec (p-nemec)
- Google
- Nandan Dubey (ndubey)
- NVIDIA
- Jonathan Hearn (splidje)
- Michael Root
- Ott Tinn
- Lukas Shrangl (luhk)
- Manuel Gamito (mgamito)
- Rémi Achard (remia)
- Joseph Goldstone (JGoldstone)
- Matthew Levine (melevine)
- Yang Yang (yangyangl, but now cometyang)
- Merwan Achibet (merwaaan)
- Anthony Nemoff (ix-anemoff)
- Damien Courtois (ix-dcourtois)
- Carl Rand (crand)
- Gregor Mückl (gmueckl)

**Prior authors, please submit a PR against this file that adds your name
above. If, at the time of your prior contributions, you were employed by a
company who would have owned your IP output, then please have someone from
that company who is authorized to do so submit a PR to add their company’s
name to the list under the statement in this file.**


---

Here are the instructions we have been given by the Linux Foundation for how
to document the contents of each file:

a. Files that consist of only contributions made entirely by companies that
   have submitted PRs as described above can have, once those PRs are merged,
   the BSD-3-Clause license information replaced with Apache-2.0 license
   information.

b. Files that contain contributions made after the change to the Apache-2.0
   license as the license for the project should include only the Apache-2.0
   license information.

c. Files that contain contributions made both before the Apache-2.0 license
   change and after the Apache-2.0 license change should include both
   BSD-3-Clause and Apache-2.0 license information. The SPDX identifier for
   these files is “BSD-3-Clause and Apache-2.0”.

d. Files that contain only contributions made prior to the Apache-2.0 license
   change should continue to include BSD-3-Clause license information (e.g.,
   no changes to BSD-3-Clause information included in those files).
